/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/* Nome: 0011_DENSTPO_USR_IMPORTAAF_DENADAI.sql                               */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a gerar uma AF no sistema da Teknisa correspondente    */
/* a cada nota fiscal de sada do operador logstico para as filiais, emitida */
/* atravs do sistema da Microsiga.                                           */
/* Criao:                                                                   */
/* 24/07/2008 - Raquel Cunha                                                  */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE USR_IMPORTAAF_DENADAI IS

   V_CDPRODUTO VARCHAR(10);
   V_CDMARCA VARCHAR(5);
   V_CODIGO VARCHAR2(20);
   V_FILIAL VARCHAR(4);
   V_FILLANC VARCHAR(4);
   V_NRAUTOFORN VARCHAR(10);
   V_OPERADOR VARCHAR(12);
   V_EMITENTE VARCHAR2(4);
   V_CDEMPRESA VARCHAR(2);
   V_IDTIPEMITGER VARCHAR(1);
   V_INSCESTA VARCHAR(16);
   V_DTPROGENTAF DATE;
   V_FORNECED VARCHAR(21);
   V_CHAVE VARCHAR2(20);

BEGIN
   V_CHAVE := ' ';
   FOR C_AFIMPORT IN
      (SELECT ZW9.D2_FILIAL, ZW9.D2_COD, ZW9.D2_PEDIDO, ZW9.D2_CLIENTE,
              ZW9.D2_QUANT, ZW9.D2_PRCVEN, ZW9.D2_TOTAL, ZW9.D2_DESCON,
              ZW9.D2_DTGRV, ZW9.D2_HRGRV, ZW9.D2_DTIMP, ZW9.D2_HRIMP,
              ZW9.ROWID
       FROM USR_ZW9 ZW9
       WHERE ZW9.D2_DTIMP IS NULL
         AND ZW9.D2_HRIMP IS NULL
       ORDER BY ZW9.D2_FILIAL, ZW9.D2_PEDIDO
       )
   LOOP
      SELECT
         MAX(FILIAL.CDFILIAL),
         MAX(NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL))
      INTO
         V_FILIAL,
         V_FILLANC
      FROM FILIAL, FILGRUPFILI
      WHERE FILGRUPFILI.USR_IDPROTHEUS = 'S'
        AND SUBSTR(FILGRUPFILI.CDGRUPFILI, 9, 2) = C_AFIMPORT.D2_FILIAL
        AND FILIAL.CDFILIAL = FILGRUPFILI.CDFILIAL;

      SELECT MAX(CDMARCA)
      INTO V_CDMARCA
      FROM PARASUPRI
      WHERE CDFILIAL = V_FILLANC;

      SELECT MAX(CDPRODUTO)
      INTO V_CDPRODUTO
      FROM PRODUTO
      WHERE CDPRODINTE = C_AFIMPORT.D2_COD;

      V_OPERADOR := '999999999999';

      SELECT MAX(CDFORNOPELOG)
      INTO V_FORNECED
      FROM FILIAL
      WHERE CDFILIAL = V_FILIAL;

      IF V_FORNECED IS NULL THEN
         SELECT MAX(CDFORNECED)
         INTO V_FORNECED
         FROM FORNECEDOR
         WHERE SUBSTR(CDEXFORNECED, 1, 6) =  C_AFIMPORT.D2_CLIENTE;
         IF V_FORNECED IS NULL THEN
            SELECT MAX(CDFORNECED)
            INTO V_FORNECED
            FROM PRODFORNCOMP
            WHERE PRODFORNCOMP.CDPRODCOMPL = V_CDPRODUTO;
         END IF;
      END IF;

      V_EMITENTE  := EMITENTE(V_FILIAL, V_CDPRODUTO, V_FORNECED);
      V_CDEMPRESA := SUBSTR(V_EMITENTE, 3, 2);
      V_IDTIPEMITGER := SUBSTR(V_EMITENTE, 1, 1);

      IF V_CHAVE <> C_AFIMPORT.D2_FILIAL||C_AFIMPORT.D2_PEDIDO THEN
         NOVO_CODIGO('AUTOFORNE'||V_FILIAL||V_FILLANC, V_CODIGO, 1);
         V_CODIGO := SUBSTR(V_CODIGO, 11, 10);
         INSERT INTO AUTOFORNE
            (CDFILDEST, CDFILLANC, NRAUTOFORN, CDOPERADOR,
             CDFORNECED, DTAUTOFORN, IDTIPOEMITAF, CDEMPRESA, USR_IDEXPORTA)
         VALUES
            (V_FILIAL, V_FILLANC, V_CODIGO, V_OPERADOR,
             V_FORNECED, TRUNC(SYSDATE), V_IDTIPEMITGER, V_CDEMPRESA, 'N');
         V_CHAVE := C_AFIMPORT.D2_FILIAL||C_AFIMPORT.D2_PEDIDO;
      END IF;

      INSERT INTO ITEMAUTF
         (CDFILDEST, CDFILLANC, NRAUTOFORN,
          CDMARCA, CDPRODUTO,  DTPROGENTAF,
          VRPREUNIAF, QTPROGENTAF, NRPARCITMAF)
      VALUES
         (V_FILIAL, V_FILLANC, V_CODIGO,
          V_CDMARCA, V_CDPRODUTO, TRUNC(SYSDATE),
          C_AFIMPORT.D2_PRCVEN, C_AFIMPORT.D2_QUANT, '00');

      SELECT DTPROGENTAF,
             NVL(CDINCESTA_FILIAL, CDINSCESTA_EMPRCNT) AS CDINSCESTA
      INTO V_DTPROGENTAF,
           V_INSCESTA
      FROM (SELECT MIN(CDINSCESTA) AS CDINSCESTA_EMPRCNT
            FROM EMPRCNTRFIL
            WHERE CDEMPRESA = V_CDEMPRESA),
           (SELECT MIN(DTPROGENTAF) AS DTPROGENTAF
            FROM ITEMAUTF
            WHERE CDFILDEST  = V_FILIAL
              AND CDFILLANC  = V_FILLANC
              AND NRAUTOFORN = V_CODIGO),
           (SELECT MIN(CDINSCESTA) AS CDINCESTA_FILIAL
            FROM FILIAL
            WHERE CDFILIAL  = V_FILIAL
              AND CDEMPRESA = V_CDEMPRESA);

      UPDATE USR_ZW9
      SET D2_DTIMP = TO_DATE(TRUNC(SYSDATE)),
          D2_HRIMP = TO_CHAR(SYSDATE, 'HH24MI')
      WHERE ROWID = C_AFIMPORT.ROWID;

      IMPOSTO_ITEMAF(V_CDEMPRESA, V_INSCESTA, V_FORNECED,
                     V_FILIAL, V_FILLANC, V_CODIGO, V_DTPROGENTAF);
   END LOOP;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_IMPORTAAF_DENADAI','5.03.014'); END;
/

